#!/usr/bin/env python

import sys

import logging
logger = logging.getLogger('preconpy')
logging.basicConfig(stream=sys.stdout, level=logging.INFO)
logger.propagate = True
logger.setLevel(logging.INFO)

import numpy as np

from ase.io import read
from ase.lattice import bulk
from ase.constraints import FixAtoms

from quippy import Potential, verbosity_push, PRINT_VERBOSE

from ase.optimize.precon import LBFGS, Pfrommer, Exp, estimate_nearest_neighbour_distance
from ase.calculators.loggingcalc import LoggingCalculator

SW = Potential('IP SW', param_filename='quip_params.xml' )
calc = LoggingCalculator(SW)

a0 = read('test_precon.xyz', format='extxyz')

r_NN = estimate_nearest_neighbour_distance(a0)

precons = {'ID' : None, 'C1' : Exp(A=0, r_cut=1.1*r_NN), 'Exp 3.0' : Exp(A=3.0),
           'Pfrommer': Pfrommer()}

if len(sys.argv) >= 2:
    precons_use = sys.argv[1:]
else:
    precons_use = precons.keys()

for precon_name in precons_use:
    precon = precons[precon_name]

    a = a0.copy()
    a.set_calculator(calc)
    calc.set_label(precon_name)

    opt = LBFGS(a, use_armijo=True, precon=precon)
    opt.run(fmax=1.0e-3)
    # results=[calc.fmax["(none)"], calc.walltime["(none)"], calc.energy_count["(none)"]]
    # np.savetxt("results."+precon_name+".txt", results)

calc.write_json('results.new.'+'_'.join(precons_use)+'.json')
