#!/usr/bin/env python

import sys
# sys.path.insert(0, '../../preconpy')

import logging
logger = logging.getLogger('ase.optimize.precon')
logging.basicConfig(stream=sys.stdout, level=logging.DEBUG)
logger.propagate = True
logger.setLevel(logging.DEBUG)

import numpy as np

from ase.io import read
from ase.lattice import bulk

from quippy import Potential, verbosity_push, PRINT_VERBOSE

from ase.optimize.precon import LBFGS, Pfrommer, Exp, estimate_nearest_neighbour_distance
from ase.calculators.loggingcalc import LoggingCalculator

# init_args='{FilePot command=vasp_driver}'
# calc_args='{vasp=vasp.openmpi potcar_files={3 POTCAR.Li 13 POTCAR.Al 29 POTCAR.Cu} persistent persistent_max_wait_time=72000}' \
# cp2k.set(cp2k_program='mpirun -np 16 /home/lam81/cp2k_quip/cp2k/exe/ifort/cp2k.popt', Run_Type='QS', cp2k_template_file='common/cp2k_input_force.template', PSF_print='DRIVER_PRINT_AND_SAVE', use_buffer=False, clean_up_files=False, do_mom_cons=False)

VASP = Potential('FilePot command=vasp_driver')
VASP.set(vasp='vasp.para', potcar_files='8 POTCAR.O 13 POTCAR.Al', persistent=True, persistent_max_wait_time=72000, persistent_restart_interval=1000)
VASP.set_default_properties(['forces', 'energy', 'stress'])
calc = LoggingCalculator(VASP, dumpjson=True)

a0 = read('gamma_Al2O3_Johannes_1.01.c0.xyz', format='extxyz')
del a0.arrays['label']

r_NN = estimate_nearest_neighbour_distance(a0)

print "got r_NN ", r_NN

precons = {'ID' : None, 'C1' : Exp(A=0, r_cut=1.1*r_NN), 'Exp 3.0' : Exp(A=3.0),
           'Pfrommer': Pfrommer()}

if len(sys.argv) >= 2:
    precons_use = sys.argv[1:]
else:
    precons_use = precons.keys()

for precon_name in precons_use:
    precon = precons[precon_name]

    a = a0.copy()
    a.set_calculator(calc)
    calc.set_label(precon_name)

    opt = LBFGS(a, precon=precon, use_armijo=True, variable_cell=True)
    opt.run(fmax=1.0e-3, smax=1e-2)
    # results=[calc.fmax["(none)"], calc.walltime["(none)"], calc.energy_count["(none)"]]
    # np.savetxt("results."+precon_name+".txt", results)

calc.write_json('results.'+'_'.join(precons_use)+'.json')
