import sys
sys.path.insert(0, '../../preconpy')

import logging
logger = logging.getLogger('preconpy')
logging.basicConfig(stream=sys.stdout, level=logging.INFO)
logger.propagate = True
logger.setLevel(logging.INFO)

import numpy as np

from ase.io import read
from ase.lattice import bulk
from ase.constraints import FixAtoms

from quippy import Potential, verbosity_push, PRINT_VERBOSE

from preconpy.precon import Exp
from preconpy.utils import LoggingCalculator
from preconpy.lbfgs import LBFGSLineSearch
from preconpy.linesearcharmijo import LineSearchArmijo

cp2k = Potential('FilePot command=/home/lam81/QUIP_official/build/linux_x86_64_gfortran/cp2k_driver')
cp2k.set(cp2k_program='mpirun -np 16 /home/lam81/cp2k_quip/cp2k/exe/ifort/cp2k.popt', Run_Type='QS', cp2k_template_file='common/cp2k_input_force.template', PSF_print='DRIVER_PRINT_AND_SAVE', use_buffer=False, clean_up_files=False, do_mom_cons=False)

calc = LoggingCalculator(cp2k)

a0 = read('common/iceVIII.xyz', format='extxyz')
a = a0.copy()
a.set_calculator(calc)

precon=Exp(A=3.0)
opt = LBFGSLineSearch(a, use_armijo=True, precon=precon)

opt.run(fmax=0.001)

results=[calc.fmax["(none)"], calc.walltime["(none)"], calc.energy_count["(none)"]]
np.savetxt("results.txt", results)
